@@ -4,5 +4,9 @@ from django.views.generic import TemplateView
 
 
 urlpatterns = patterns('',
-    url(_(r'register/$'), TemplateView.as_view(template_name='i18nurls/dummy.html'), name='register'),
+    url(
+        _(r'register/$'),
+        TemplateView.as_view(template_name='i18nurls/dummy.html'),
+        name='register'
+    ),
 )
